==> react-atom-input-4.18.0.tgz: package/lib/Input/Component/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomInput-input';
var SIZES = {
  MEDIUM: 'm',
  SMALL: 's',
  XSMALL: 'xs'
};
var INPUT_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};
var DEFAULT_PROPS = {
  SIZE: SIZES.MEDIUM,
  ON_ENTER_KEY: 'Enter',
  TAB_INDEX: -1,
  ON_KEY_DOWN: function ON_KEY_DOWN() {},
  ON_ENTER: function ON_ENTER() {},
  ON_CHANGE: function ON_CHANGE() {}
};

var getClassNames = function getClassNames(_ref) {
  var size = _ref.size,
      charsSize = _ref.charsSize,
      hideInput = _ref.hideInput,
      noBorder = _ref.noBorder,
      readOnly = _ref.readOnly,
      errorState = _ref.errorState,
      state = _ref.state;
  return cx(BASE_CLASS, BASE_CLASS + "-" + size, charsSize && BASE_CLASS + "--size", hideInput && BASE_CLASS + "--hidden", noBorder && BASE_CLASS + "--noBorder", readOnly && BASE_CLASS + "--readOnly", errorState && BASE_CLASS + "--" + INPUT_STATES.ERROR, errorState === false && BASE_CLASS + "--" + INPUT_STATES.SUCCESS, state && BASE_CLASS + "--" + state);
};

var Input = function Input(_ref2) {
  var disabled = _ref2.disabled,
      readOnly = _ref2.readOnly,
      hideInput = _ref2.hideInput,
      noBorder = _ref2.noBorder,
      id = _ref2.id,
      name = _ref2.name,
      onBlur = _ref2.onBlur,
      onFocus = _ref2.onFocus,
      placeholder = _ref2.placeholder,
      reference = _ref2.reference,
      _ref2$size = _ref2.size,
      size = _ref2$size === void 0 ? DEFAULT_PROPS.SIZE : _ref2$size,
      errorState = _ref2.errorState,
      state = _ref2.state,
      type = _ref2.type,
      value = _ref2.value,
      charsSize = _ref2.charsSize,
      _ref2$tabIndex = _ref2.tabIndex,
      tabIndex = _ref2$tabIndex === void 0 ? DEFAULT_PROPS.TAB_INDEX : _ref2$tabIndex,
      maxLength = _ref2.maxLength,
      minLength = _ref2.minLength,
      min = _ref2.min,
      max = _ref2.max,
      step = _ref2.step,
      autoComplete = _ref2.autoComplete,
      _ref2$onChange = _ref2.onChange,
      onChange = _ref2$onChange === void 0 ? DEFAULT_PROPS.ON_CHANGE : _ref2$onChange,
      _ref2$onEnter = _ref2.onEnter,
      onEnter = _ref2$onEnter === void 0 ? DEFAULT_PROPS.ON_ENTER : _ref2$onEnter,
      _ref2$onEnterKey = _ref2.onEnterKey,
      onEnterKey = _ref2$onEnterKey === void 0 ? DEFAULT_PROPS.ON_ENTER_KEY : _ref2$onEnterKey,
      _ref2$onKeyDown = _ref2.onKeyDown,
      onKeyDown = _ref2$onKeyDown === void 0 ? DEFAULT_PROPS.ON_KEY_DOWN : _ref2$onKeyDown,
      required = _ref2.required,
      pattern = _ref2.pattern,
      inputMode = _ref2.inputMode;

  var changeHandler = function changeHandler(ev) {
    var _ev$target = ev.target,
        value = _ev$target.value,
        name = _ev$target.name;
    onChange(ev, {
      value: value,
      name: name
    });
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var _ev$target2 = ev.target,
        value = _ev$target2.value,
        name = _ev$target2.name;
    var key = ev.key;
    onKeyDown(ev, {
      value: value,
      name: name
    });
    if (key === onEnterKey) onEnter(ev, {
      value: value,
      name: name
    });
  };

  var className = getClassNames({
    size: size,
    charsSize: charsSize,
    hideInput: hideInput,
    noBorder: noBorder,
    readOnly: readOnly,
    errorState: errorState,
    state: state
  });
  return React.createElement("input", {
    className: className,
    tabIndex: tabIndex,
    disabled: disabled || readOnly,
    readOnly: readOnly,
    id: id,
    name: name,
    onChange: changeHandler,
    onFocus: onFocus,
    onBlur: onBlur,
    onKeyDown: handleKeyDown,
    placeholder: placeholder,
    ref: reference,
    type: type,
    value: value,
    size: charsSize,
    maxLength: maxLength,
    minLength: minLength,
    max: max,
    min: min,
    step: step,
    autoComplete: autoComplete,
    required: required,
    pattern: pattern,
    inputMode: inputMode
  });
};

export default Input;
export { SIZES as inputSizes, INPUT_STATES as inputStates };

==> react-atom-input-4.19.0.tgz: package/lib/Input/Component/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomInput-input';
var SIZES = {
  MEDIUM: 'm',
  SMALL: 's',
  XSMALL: 'xs'
};
var INPUT_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};
var DEFAULT_PROPS = {
  SIZE: SIZES.MEDIUM,
  ON_ENTER_KEY: 'Enter',
  TAB_INDEX: -1,
  ON_KEY_DOWN: function ON_KEY_DOWN() {},
  ON_ENTER: function ON_ENTER() {},
  ON_CHANGE: function ON_CHANGE() {}
};

var getClassNames = function getClassNames(_ref) {
  var size = _ref.size,
      charsSize = _ref.charsSize,
      hideInput = _ref.hideInput,
      noBorder = _ref.noBorder,
      readOnly = _ref.readOnly,
      errorState = _ref.errorState,
      state = _ref.state;
  return cx(BASE_CLASS, BASE_CLASS + "-" + size, charsSize && BASE_CLASS + "--size", hideInput && BASE_CLASS + "--hidden", noBorder && BASE_CLASS + "--noBorder", readOnly && BASE_CLASS + "--readOnly", errorState && BASE_CLASS + "--" + INPUT_STATES.ERROR, errorState === false && BASE_CLASS + "--" + INPUT_STATES.SUCCESS, state && BASE_CLASS + "--" + state);
};

var Input = function Input(_ref2) {
  var disabled = _ref2.disabled,
      readOnly = _ref2.readOnly,
      hideInput = _ref2.hideInput,
      noBorder = _ref2.noBorder,
      id = _ref2.id,
      name = _ref2.name,
      onBlur = _ref2.onBlur,
      onFocus = _ref2.onFocus,
      placeholder = _ref2.placeholder,
      reference = _ref2.reference,
      _ref2$size = _ref2.size,
      size = _ref2$size === void 0 ? DEFAULT_PROPS.SIZE : _ref2$size,
      errorState = _ref2.errorState,
      state = _ref2.state,
      type = _ref2.type,
      value = _ref2.value,
      charsSize = _ref2.charsSize,
      _ref2$tabIndex = _ref2.tabIndex,
      tabIndex = _ref2$tabIndex === void 0 ? DEFAULT_PROPS.TAB_INDEX : _ref2$tabIndex,
      maxLength = _ref2.maxLength,
      minLength = _ref2.minLength,
      min = _ref2.min,
      max = _ref2.max,
      step = _ref2.step,
      autoComplete = _ref2.autoComplete,
      autoFocus = _ref2.autoFocus,
      _ref2$onChange = _ref2.onChange,
      onChange = _ref2$onChange === void 0 ? DEFAULT_PROPS.ON_CHANGE : _ref2$onChange,
      _ref2$onEnter = _ref2.onEnter,
      onEnter = _ref2$onEnter === void 0 ? DEFAULT_PROPS.ON_ENTER : _ref2$onEnter,
      _ref2$onEnterKey = _ref2.onEnterKey,
      onEnterKey = _ref2$onEnterKey === void 0 ? DEFAULT_PROPS.ON_ENTER_KEY : _ref2$onEnterKey,
      _ref2$onKeyDown = _ref2.onKeyDown,
      onKeyDown = _ref2$onKeyDown === void 0 ? DEFAULT_PROPS.ON_KEY_DOWN : _ref2$onKeyDown,
      required = _ref2.required,
      pattern = _ref2.pattern,
      inputMode = _ref2.inputMode;

  var changeHandler = function changeHandler(ev) {
    var _ev$target = ev.target,
        value = _ev$target.value,
        name = _ev$target.name;
    onChange(ev, {
      value: value,
      name: name
    });
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var _ev$target2 = ev.target,
        value = _ev$target2.value,
        name = _ev$target2.name;
    var key = ev.key;
    onKeyDown(ev, {
      value: value,
      name: name
    });
    if (key === onEnterKey) onEnter(ev, {
      value: value,
      name: name
    });
  };

  var className = getClassNames({
    size: size,
    charsSize: charsSize,
    hideInput: hideInput,
    noBorder: noBorder,
    readOnly: readOnly,
    errorState: errorState,
    state: state
  });
  return /*#__PURE__*/React.createElement("input", {
    className: className,
    tabIndex: tabIndex,
    disabled: disabled || readOnly,
    readOnly: readOnly,
    id: id,
    name: name,
    onChange: changeHandler,
    onFocus: onFocus,
    onBlur: onBlur,
    onKeyDown: handleKeyDown,
    placeholder: placeholder,
    ref: reference,
    type: type,
    value: value,
    size: charsSize,
    maxLength: maxLength,
    minLength: minLength,
    max: max,
    min: min,
    step: step,
    autoComplete: autoComplete,
    autoFocus: autoFocus,
    required: required,
    pattern: pattern,
    inputMode: inputMode
  });
};

export default Input;
export { SIZES as inputSizes, INPUT_STATES as inputStates };
